# Doesn't require any BIOS/copyrighted material, so it can go in core.

Name:           desmume
Version:        0.9.11
Release:        %mkrel 10
Summary:        A Nintendo DS emulator
Group:          Emulators
License:        GPLv2+
URL:            https://desmume.org/
Source0:        https://downloads.sourceforge.net/project/desmume/desmume/%{version}/%{name}-%{version}.tar.gz
# Do not look into builddir (Fedora)
Patch0:         desmume-0.9-dontlookinbuilddir.patch
# Use system tinyxml instead of the embedded copy
Patch1:         desmume-0.9.11-tinyxml.patch
# Compile with gcc6
Patch2:         gcc6_fixes.patch
# Fix check for null terminator
Patch3:         desmume-0.9.11-null_terminator.patch

BuildRequires:  desktop-file-utils
BuildRequires:  gtkglext-devel
BuildRequires:  intltool
BuildRequires:  pkgconfig(libglade-2.0)
BuildRequires:  pkgconfig(lua)
BuildRequires:  pkgconfig(openal)
BuildRequires:  pkgconfig(sdl)
BuildRequires:  pkgconfig(soundtouch)
BuildRequires:  pkgconfig(zziplib)
BuildRequires:  tinyxml-devel

%description
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

#----------------------------------------------------------------------------

%package gtk
Summary:        A Nintendo DS emulator (Gtk GUI version)
Group:          Emulators
Provides:       %{name} = %{version}-%{release}

%description gtk
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

This is the GTK version.

%files gtk
%doc AUTHORS ChangeLog README README.LIN
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/%{name}.*
%{_gamesbindir}/%{name}
%{_mandir}/man1/%{name}.1*

#----------------------------------------------------------------------------

%package glade
Summary:        A Nintendo DS emulator (Glade GUI version)
Group:          Emulators
Provides:       %{name} = %{version}-%{release}

%description glade
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

This is the GTK/Glade version.

%files glade -f %{name}-glade.lang
%doc AUTHORS ChangeLog README README.LIN
%{_datadir}/applications/%{name}-glade.desktop
%{_datadir}/pixmaps/%{name}-glade.*
%{_gamesbindir}/%{name}-glade
%{_gamesdatadir}/%{name}-glade/
%{_mandir}/man1/%{name}-glade.1*

#----------------------------------------------------------------------------

%package cli
Summary:        A Nintendo DS emulator (CLI version)
Group:          Emulators
Provides:       %{name} = %{version}-%{release}

%description cli
DeSmuME is a Nintendo DS emulator running homebrew demos and commercial games.

This is the CLI version.

%files cli
%doc AUTHORS ChangeLog README README.LIN
%{_gamesbindir}/%{name}-cli
%{_mandir}/man1/%{name}-cli.1*

#----------------------------------------------------------------------------

%prep
%setup -q
sed -i 's/\r//' src/MMU_timing.h
%autopatch -p1

# Remove bundled tinyxml
rm -rf src/utils/tinyxml

# Fix end-of-line encoding
sed -i 's/\r//' AUTHORS

# Fix file encoding
for txtfile in ChangeLog AUTHORS
do
    iconv --from=ISO-8859-1 --to=UTF-8 $txtfile > tmp
    touch -r $txtfile tmp
    mv tmp $txtfile
done

# Fix glade path
sed -i 's|gladedir = $(datadir)/desmume/glade|gladedir = $(datadir)/games/desmume-glade/|g' src/gtk-glade/Makefile.{am,in}

# Fix gettext package name
sed -i 's|GETTEXT_PACKAGE=desmume|GETTEXT_PACKAGE=desmume-glade|g' configure{,.ac}

%build
%configure --bindir=%{_gamesbindir} \
               --enable-openal \
               --enable-glade
%make_build

%install
%make_install

# Rename installed icon and duplicate it for the glade package
pushd %{buildroot}%{_datadir}/pixmaps/
mv DeSmuME.xpm %{name}.xpm
cp %{name}.xpm %{name}-glade.xpm
popd

# Fix categories and icons of the desktop files
mkdir -p %{buildroot}%{_datadir}/applications
desktop-file-edit \
  --remove-category GNOME \
  --remove-category GTK \
  --set-icon %{name} \
  %{buildroot}%{_datadir}/applications/%{name}.desktop

desktop-file-edit \
  --remove-category GNOME \
  --remove-category GTK \
  --set-icon %{name}-glade \
  %{buildroot}%{_datadir}/applications/%{name}-glade.desktop

%find_lang %{name}-glade


%changelog
* Fri Jun 27 2025 umeabot <umeabot> 0.9.11-10.mga10
+ Revision: 2213673
- Mageia 10 Mass Rebuild

* Fri Apr 01 2022 umeabot <umeabot> 0.9.11-9.mga9
+ Revision: 1839581
- Mageia 9 Mass Rebuild

* Mon Jan 24 2022 neoclust <neoclust> 0.9.11-8.mga9
+ Revision: 1769601
- Rebuild against new soundtouch

* Sun Sep 26 2021 luigiwalser <luigiwalser> 0.9.11-7.mga9
+ Revision: 1746593
- rebuild for soundtouch

* Tue Nov 03 2020 akien <akien> 0.9.11-6.mga8
+ Revision: 1642043
- Rebuild in core as it doesn't require tainted material to work

* Fri Feb 21 2020 umeabot <umeabot> 0.9.11-5.mga8.tainted
+ Revision: 1548864
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Feb 24 2019 wally <wally> 0.9.11-4.mga7.tainted
+ Revision: 1369871
- drop unused agg BR

* Sun Oct 07 2018 daviddavid <daviddavid> 0.9.11-3.mga7.tainted
+ Revision: 1318349
- add two patches to fix build with new gcc
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Sun Jan 03 2016 luigiwalser <luigiwalser> 0.9.11-2.mga6.tainted
+ Revision: 918983
- rebuild for soundtouch

* Mon Sep 07 2015 zezinho <zezinho> 0.9.11-1.mga6.tainted
+ Revision: 873959
- new version 0.9.11

* Wed Oct 15 2014 umeabot <umeabot> 0.9.10-3.mga5.tainted
+ Revision: 749363
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.9.10-2.mga5.tainted
+ Revision: 678717
- Mageia 5 Mass Rebuild

* Thu May 08 2014 akien <akien> 0.9.10-1.mga5.tainted
+ Revision: 621288
- Add warning that this package should be submitted to tainted
- imported package desmume (based off Fedora's SRPM)

